@@ -4,17 +4,20 @@ use strict;
 use Exporter;
 use Test::More;
 use FileHandle;
+use Config;
 
 use vars qw( @EXPORT @ISA $VERSION );
 
 $VERSION = sprintf "%d.%02d%02d", q/0.10.1/ =~ /(\d+)/g;
 
 @ISA = qw( Exporter );
-@EXPORT = qw( Run_Script Write_Script Setup_Cache $set_env $single_quote
+@EXPORT = qw( Init_For_Run Run_Script Write_Script Setup_Cache $set_env $single_quote
               $command_separator );
 
 use vars qw( $single_quote $command_separator $set_env );
 
+my $path_to_perl = $Config{perlpath};
+
 if ($^O eq 'MSWin32')
 {
   $set_env = 'set';
@@ -30,6 +33,18 @@ else
 
 # ---------------------------------------------------------------------------
 
+sub Init_For_Run
+{
+  my $test_script_name = shift;
+  my $script = shift;
+  my $clear_cache = shift;
+
+  Write_Script($test_script_name,$script);
+  Setup_Cache($test_script_name,$script,$clear_cache);
+}
+
+# ---------------------------------------------------------------------------
+
 # This function executes three tests, one for each of the expected_ variables.
 # If any of the expected_ variables are the string "<SKIP>", any value will be
 # accepted.
@@ -37,18 +52,13 @@ else
 sub Run_Script
 {
   my $test_script_name = shift;
-  my $script = shift;
   my $expected_stdout = shift;
   my $expected_stderr = shift;
   my $expected_cached = shift;
   my $message = shift;
-  my $clear_cache = shift;
 
   local $Test::Builder::Level = 2;
 
-  Write_Script($test_script_name,$script);
-  Setup_Cache($test_script_name,$script,$clear_cache);
-
   # Save STDERR and redirect temporarily to nothing. This will prevent the
   # test script from emitting output to STDERR
   {
@@ -60,7 +70,7 @@ sub Run_Script
     my $script_results;
     
     {
-      my @standard_inc = split /###/, `$^X -e '\$" = "###";print "\@INC"'`;
+      my @standard_inc = split /###/, `$path_to_perl -e '\$" = "###";print "\@INC"'`;
       my @extra_inc;
       foreach my $inc (@INC)
       {
@@ -71,11 +81,11 @@ sub Run_Script
       if (@extra_inc)
       {
         local $" = ' -I';
-        $script_results = `$^X -I@extra_inc $test_script_name`;
+        $script_results = `$path_to_perl -I@extra_inc $test_script_name`;
       }
       else
       {
-        $script_results = `$^X $test_script_name`;
+        $script_results = `$path_to_perl $test_script_name`;
       }
     }
     
